@@ -34,7 +34,7 @@ int isansi(char *);
 int isaction(char *);
 int isctcp(char *);
 int wordcount(char *);
-int parse(char *, int, char *, char *, int);
+int parse(char *, int, char *, char *, int, int);
 void striplf(char *);
 void stripchars(char *, char *);
 void stripcntrl(char *);
@@ -106,7 +106,7 @@ int wordcount(char *line)
 	ppos = 0;
 	words = 0;
 	while(1) {
-		nppos = parse(line, ppos, " ", word, STRINGLEN);
+		nppos = parse(line, ppos, " ", word, STRINGLEN, 0);
 		if(nppos == ppos || nppos < 0) {
 			break;
 		}
@@ -320,30 +320,49 @@ int isnumber(char *line)
 	return 1;
 }
 
-int parse(char *from, int pos, char *delim, char *to, int to_length)
+int parse(char *from, int pos, char *delim, char *to, int to_length, int fixed)
 {
         int i;
         int j;
         int k;
         int len;
+	int found_delim;
 
         memset(to, 0, to_length + 1);
 	i = pos;
 	k = 0;
 	j = strlen(delim);
 	len = strlen(from);
+	found_delim = 0;
 	while(i < len && k < to_length) {
-                if(!strncasecmp(from + i, delim, j)) {
-                        i += j;
-                        break;
-                }
+		/* loop until delim found, respecting 
+		   length constraints */
+		if(fixed && !strncasecmp(from + i, delim, j)) {
+			found_delim = 1;
+			break;
+		}
+		if(!fixed && from[i] == delim[0]) {
+			found_delim = 1;
+			break;
+		}
                 to[k++] = from[i++];
-        }
+	}
+	if(found_delim) {
+		/* advance until next non-delim character */
+		if(fixed) {
+			i += j;
+		} else {
+			while((from[i] == delim[0]) && (i < len)) {
+				i++;
+			}
+		}
+	}
         if(k >= to_length) {
+		/* insufficient buffer space */
                 return -1;
         }
         to[k] = '\0';
-        return i;
+	return i;
 }
 
 void secondstostring(time_t seconds, char *string, int maxlen)
