@@ -36,7 +36,7 @@ extern int emptyline(char *);
 extern int iscomment(char *);
 extern int isnumber(char *);
 extern int wordcount(char *);
-extern int parse(char *, int, char *, char *, int);
+extern int parse(char *, int, char *, char *, int, int);
 extern void striplf(char *);
 extern void stripansi(char *);
 extern void stripmirc(char *);
