@@ -74,13 +74,13 @@ void parseirc(char *serveroutput)
 	}
 	striplf(serveroutput);
 	ppos = 0;
-	if((ppos = parse(serveroutput, ppos, " ", prefix, STRINGLEN)) < 0) {
+	if((ppos = parse(serveroutput, ppos, " ", prefix, STRINGLEN, 0)) < 0) {
 		return;
 	}
-	if((ppos = parse(serveroutput, ppos, " ", command, TINYSTRINGLEN)) < 0) {
+	if((ppos = parse(serveroutput, ppos, " ", command, TINYSTRINGLEN, 0)) < 0) {
 		return;
 	}
-	if((ppos = parse(serveroutput, ppos, " ", params, STRINGLEN)) < 0) {
+	if((ppos = parse(serveroutput, ppos, " ", params, STRINGLEN, 0)) < 0) {
 		return;
 	}
 	/* the rest of the serveroutput is serveroutput + ppos */
@@ -130,14 +130,14 @@ void parseirc(char *serveroutput)
 		restptr++;
 		restpos = 0;
 		while(1) {
-			nrestpos = parse(restptr, restpos, " ", outstring, STRINGLEN);
+			nrestpos = parse(restptr, restpos, " ", outstring, STRINGLEN, 0);
 			if(nrestpos == restpos || nrestpos < 0) {
 				break;
 			}
 			restpos = nrestpos;
 			memset(nick, 0, NICKLEN + 1);
 			tpos = 0;
-			if((tpos = parse(outstring, tpos, "=", nick, NICKLEN)) < 0) {
+			if((tpos = parse(outstring, tpos, "=", nick, NICKLEN, 1)) < 0) {
 				return;
 			}
 			if(!strlen(nick)) {
@@ -166,7 +166,7 @@ void parseirc(char *serveroutput)
 	}
 	if(!strcasecmp(command, "332")) {
 		restpos = 0;
-		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
 			return;
 		}
 		if((this = getchptr(channel)) == NULL) {
@@ -193,15 +193,15 @@ void parseirc(char *serveroutput)
 	}
 	if(!strcasecmp(command, "353")) {
 		restpos = 0;
-		if((restpos = parse(restptr, restpos, " ", mode, CHANLEN)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", mode, CHANLEN, 0)) < 0) {
 			return;
 		}
-		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
 			return;
 		}
 		oer_debug(OER_DEBUG_INFO, "parseirc(353)->%s\n", channel);
 		while(1) {
-			nrestpos = parse(restptr, restpos, " ", nick, NICKLEN);
+			nrestpos = parse(restptr, restpos, " ", nick, NICKLEN, 0);
 			if(nrestpos == restpos || nrestpos < 0) {
 				break;
 			}
@@ -230,7 +230,7 @@ void parseirc(char *serveroutput)
 	if(!strcasecmp(command, "366")) {
 		/* 366 is sent after /NAMES, means the join is complete */
 		restpos = 0;
-		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
 			return;
 		}
 		oer_debug(OER_DEBUG_INFO, "parseirc(366)->channel %s\n", channel);
@@ -278,7 +278,7 @@ void parseirc(char *serveroutput)
 	if(!strcasecmp(command, "471") || !strcasecmp(command, "473") \
 	   || !strcasecmp(command, "474") || !strcasecmp(command, "475")) {
 		restpos = 0;
-		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
 			return;
 		}
 		oer_debug(OER_DEBUG_INFO, "parseirc(%s)->%s\n", command, channel);
@@ -300,10 +300,10 @@ void parseirc(char *serveroutput)
 	if(!strcasecmp(command, "484")) {
 		/* undernet extension, protected user */
 		restpos = 0;
-		if((restpos = parse(restptr, restpos, " ", nick, NICKLEN)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", nick, NICKLEN, 0)) < 0) {
 			return;
 		}
-		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
 			return;
 		}
 		oer_debug(OER_DEBUG_INFO, "parseirc(484)->nick %s on %s is a IRC operator\n", nick, channel);
@@ -326,7 +326,7 @@ void parseirc(char *serveroutput)
 			strncpy(channel, params, CHANLEN);
 		}
 		tpos = 0;
-		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN)) < 0) {
+		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
 		strncpy(host, prefix + 1 + tpos, HOSTLEN);
@@ -417,7 +417,7 @@ void parseirc(char *serveroutput)
 	}
 	if(!strcasecmp(command, "PRIVMSG")) {
 		tpos = 0;
-		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN)) < 0) {
+		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
 		strncpy(host, prefix + 1 + tpos, HOSTLEN);
@@ -428,7 +428,7 @@ void parseirc(char *serveroutput)
 	}
 	if(!strcasecmp(command, "QUIT")) {
 		tpos = 0;
-		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN)) < 0) {
+		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
 		strncpy(host, prefix + 1 + tpos, HOSTLEN);
@@ -452,7 +452,7 @@ void parseirc(char *serveroutput)
 	}
 	if(!strcasecmp(command, "PART")) {
 		tpos = 0;
-		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN)) < 0) {
+		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
 		strncpy(host, prefix + 1 + tpos, HOSTLEN);
@@ -476,7 +476,7 @@ void parseirc(char *serveroutput)
 	}
 	if(!strcasecmp(command, "NICK")) {
 		tpos = 0;
-		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN)) < 0) {
+		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
 		strncpy(host, prefix + 1 + tpos, HOSTLEN);
@@ -511,13 +511,13 @@ void parseirc(char *serveroutput)
 	}
 	if(!strcasecmp(command, "KICK")) {
 		tpos = 0;
-		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN)) < 0) {
+		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
 		strncpy(host, prefix + 1 + tpos, HOSTLEN);
 		strncpy(channel, params, CHANLEN);
 		restpos = 0;
-		if((restpos = parse(restptr, restpos, " ", target, NICKLEN)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", target, NICKLEN, 0)) < 0) {
 			return;
 		}
 		if(isme(target)) {
@@ -541,13 +541,13 @@ void parseirc(char *serveroutput)
 	}
 	if(!strcasecmp(command, "MODE")) {
 		tpos = 0;
-		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN)) < 0) {
+		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
 		strncpy(host, prefix + 1 + tpos, HOSTLEN);
 		strncpy(channel, params, CHANLEN);
 		restpos = 0;
-		if((restpos = parse(restptr, restpos, " ", mode, CHANLEN)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", mode, CHANLEN, 0)) < 0) {
 			return;
 		}
 		if(mode[0] == ':') {
@@ -572,7 +572,7 @@ void parseirc(char *serveroutput)
 		bans = 0;
 		deops = 0;
 		while(1) {
-			nrestpos = parse(restptr, restpos, " ", target, NICKLEN);
+			nrestpos = parse(restptr, restpos, " ", target, NICKLEN, 0);
 			if(nrestpos == restpos || nrestpos < 0) {
 				break;
 			}
@@ -650,12 +650,12 @@ void parseirc(char *serveroutput)
 	}
 	if(!strcasecmp(command, "INVITE")) {
 		tpos = 0;
-		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN)) < 0) {
+		if((tpos = parse(prefix + 1, tpos, "!", nick, NICKLEN, 1)) < 0) {
 			return;
 		}
 		strncpy(host, prefix + 1 + tpos, HOSTLEN);
 		restpos = 0;
-		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
 			return;
 		}
 		oer_debug(OER_DEBUG_INFO, "parseirc(INVITE)->%s invited me to %s\n", nick, channel + 1);
@@ -781,12 +781,12 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 	oer_debug(OER_DEBUG_INFO, "parsecommand->message from %s!%s target is %s and command is %s\n", nick, host, target, commandline);
 	/* command line parsing begins here, first parameter = the command */
         ppos = 0;
-        if((ppos = parse(commandline, ppos, " ", command, STRINGLEN)) < 0) {
+        if((ppos = parse(commandline, ppos, " ", command, STRINGLEN, 0)) < 0) {
                 return;
         }
 	prevppos = ppos;
 	/* second is either the channel or first parameter to the command */
-        if((ppos = parse(commandline, ppos, " ", channel, CHANLEN)) < 0) {
+        if((ppos = parse(commandline, ppos, " ", channel, CHANLEN, 0)) < 0) {
                 return;
         }
 	if(isme(target)) {
@@ -856,7 +856,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
                         return;
                 }
 		ppos = 0;
-		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN)) < 0) {
+		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
 		if(!strlen(p1) || !strlen(restptr + ppos)) {
@@ -872,7 +872,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
                         return;
                 }
 		ppos = 0;
-		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN)) < 0) {
+		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
 		if(!strlen(p1) || !strlen(restptr + ppos)) {
@@ -913,10 +913,10 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
                         return;
                 }
 		ppos = 0;
-		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN)) < 0) {
+		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
-		if((ppos = parse(restptr, ppos, " ", p2, STRINGLEN)) < 0) {
+		if((ppos = parse(restptr, ppos, " ", p2, STRINGLEN, 0)) < 0) {
 			return;
 		}
 		if(!strlen(p1) || !strlen(p2)) {
@@ -942,7 +942,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 			return;
 		}
 		ppos = 0;
-		ppos = parse(restptr, ppos, " ", p1, STRINGLEN);
+		ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0);
 		if((strlen(p1) > 0) && !strcasecmp(p1, "auto")) {
 			lockchan(channel, 1, nick, host);
 		} else {
@@ -1051,7 +1051,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		/* op all given nicks */
 		ppos = 0;
 		while(1) {
-			nppos = parse(restptr, ppos, " ", p1, STRINGLEN);
+			nppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0);
 			if(nppos == ppos || nppos < 0) {
 				break;
 			}
@@ -1082,7 +1082,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		/* de-op all given nicks */
 		ppos = 0;
 		while(1) {
-			nppos = parse(restptr, ppos, " ", p1, STRINGLEN);
+			nppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0);
 			if(nppos == ppos || nppos < 0) {
 				break;
 			}
@@ -1110,7 +1110,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		/* voice all given nicks */
 		ppos = 0;
 		while(1) {
-			nppos = parse(restptr, ppos, " ", p1, STRINGLEN);
+			nppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0);
 			if(nppos == ppos || nppos < 0) {
 				break;
 			}
@@ -1134,7 +1134,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		/* ban all given nicks */
 		ppos = 0;
 		while(1) {
-			nppos = parse(restptr, ppos, " ", p1, STRINGLEN);
+			nppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0);
 			if(nppos == ppos || nppos < 0) {
 				break;
 			}
@@ -1156,7 +1156,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		/* unban all given nicks */
 		ppos = 0;
 		while(1) {
-			nppos = parse(restptr, ppos, " ", p1, STRINGLEN);
+			nppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0);
 			if(nppos == ppos || nppos < 0) {
 				break;
 			}
@@ -1176,7 +1176,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 			return;
 		}
 		ppos = 0;
-		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN)) < 0) {
+		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
 		/* bankick user, with or without given reason */
@@ -1194,7 +1194,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 			return;
 		}
 		ppos = 0;
-		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN)) < 0) {
+		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
 		/* kick user, with or without given reason */
@@ -1233,7 +1233,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 			return;
 		}
 		ppos = 0;
-		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN)) < 0) {
+		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
 		if(!strlen(p1)) {
@@ -1247,7 +1247,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		/* process all modes */
 		counter = 1;
 		while(1) {
-			nppos = parse(restptr, ppos, " ", p2, STRINGLEN);
+			nppos = parse(restptr, ppos, " ", p2, STRINGLEN, 0);
 			if(nppos == ppos || nppos < 0) {
 				break;
 			}
